@@ -1,11 +1,12 @@
 from typing import List, Literal, Optional, Tuple
 
 from grai_client.endpoints.client import BaseClient
-from grai_client.schemas.edge import Edge
-from grai_client.schemas.node import Node
 from grai_client.update import update
+from grai_schemas.base import Edge, Node
+
 from grai_source_postgres.adapters import adapt_to_client
 from grai_source_postgres.loader import PostgresConnector
+from grai_source_postgres.package_definitions import config
 
 
 def get_nodes_and_edges(
